@@ -50,7 +50,7 @@ __type__ = {
 
 class Format:
     def __init__(self,
-                 *value,
+                 *values,
                  _color="default",
                  _effect="default",
                  _background="default",
@@ -63,7 +63,7 @@ class Format:
                  ):
         """
 
-        :param value: 要打印的对象，可不输入，在打印函数输入
+        :param values: 要打印的对象，可不输入，在打印函数输入
         :param _color: 打印颜色
         :param _effect: 打印亮度
         :param _background: 打印背景
@@ -74,7 +74,7 @@ class Format:
         :param file: 文件
         :param flush: 流
         """
-        self.value = value
+        self.values = values
         self.color = _color
         self.effect = _effect
         self.background = _background
@@ -87,17 +87,17 @@ class Format:
         self.error = None
 
     @property
-    def value(self):
-        return self.__value
+    def values(self):
+        return self.__values
 
-    @value.setter
-    def value(self, value):
+    @values.setter
+    def values(self, value):
         if isinstance(value, tuple):
-            self.__value = list(value)
+            self.__values = list(value)
         elif isinstance(value, list):
-            self.__value = value
+            self.__values = value
         else:
-            self.__value = [value]
+            self.__values = [value]
 
     @property
     def color(self):
@@ -186,8 +186,8 @@ class Format:
             __effect = self.effect
             __background = self.background
         __print_temp = "\033[%s;%s%sm" % (__effect__[__effect], __background__[__background], __color__[__color])
-        if self.value:
-            for __value_i in self.value:
+        if self.values:
+            for __value_i in self.values:
                 __print_temp += "%s%s" % (__value_i, self.sep)
             __print_temp = __print_temp[:-len(self.sep)]
         __print_temp += "\033[0m%s" % self.end
@@ -196,7 +196,13 @@ class Format:
     def __repr__(self):
         return self.__str__()
 
-    def print(self, *value):
+    def print(self,
+              *values,
+              sep=None,
+              end=None,
+              file=None,
+              flush=None
+              ):
         if self.type is not None:
             __color = self.type[0]
             __effect = self.type[1]
@@ -205,22 +211,72 @@ class Format:
             __color = self.color
             __effect = self.effect
             __background = self.background
-        print("\033[%s;%s%sm" % (__effect__[__effect], __background__[__background], __color__[__color]),
-              sep="", end="", file=self.file, flush=self.flush)
-        if value:
-            print(*value, sep=self.sep, end="\033[0m%s" % self.end, file=self.file, flush=self.flush)
+        __sep = self.sep if sep is None else sep
+        __end = self.end if end is None else end
+        __file = self.file if file is None else file
+        __flush = self.flush if flush is None else flush
+        print(
+            "\033[%s;%s%sm" % (__effect__[__effect], __background__[__background], __color__[__color]),
+            sep="",
+            end="",
+            file=__file,
+            flush=__flush
+        )
+        if values:
+            print(
+                *values,
+                sep=__sep,
+                end="\033[0m%s" % __end,
+                file=__file,
+                flush=__flush
+            )
         else:
-            print(*self.value, sep=self.sep, end="\033[0m%s" % self.end, file=self.file, flush=self.flush)
+            print(
+                *self.values,
+                sep=__sep,
+                end="\033[0m%s" % __end,
+                file=__file,
+                flush=__flush
+            )
 
-    def __fill(self, __width, __fillchar=" ", __type="L", __parameter=0.35):
-        if len(__fillchar) != 1:
+    def __fill(self, fill_width, fill_char=" ", fill_type="L", fill_parameter=0.35):
+        if len(fill_char) != 1:
             raise OverflowError("填充字符长度只能为1")
-        if self.value:
+        if self.values:
             __value_temp = []
-            for __value_i in self.value:
-                __value_temp.append(str_just(str(__value_i), __width, __fillchar, _type=__type, _parameter=__parameter))
+            for __value_i in self.values:
+                __value_temp.append(
+                    str_just(str(__value_i), fill_width, fill_char, _type=fill_type, _parameter=fill_parameter)
+                )
+            return self.copy(*__value_temp)
+        return self.copy()
+
+    def left_just(self, fill_width, fill_char=" ", fill_parameter=0.60):
+        return self.__fill(fill_width, fill_char, fill_type="L", fill_parameter=fill_parameter)
+
+    def right_just(self, fill_width, fill_char=" ", fill_parameter=0.60):
+        return self.__fill(fill_width, fill_char, fill_type="R", fill_parameter=fill_parameter)
+
+    def center(self, fill_width, fill_char=" ", fill_parameter=0.60):
+        return self.__fill(fill_width, fill_char, fill_type="C", fill_parameter=fill_parameter)
+
+    def copy(self, *values):
+        if values:
             return Format(
-                *__value_temp,
+                *values,
+                _color=self.color,
+                _effect=self.effect,
+                _background=self.background,
+                _type=self.type,
+                _isprint=self.isPrint,
+                sep=self.sep,
+                end=self.end,
+                file=self.file,
+                flush=self.flush
+            )
+        else:
+            return Format(
+                *self.values,
                 _color=self.color,
                 _effect=self.effect,
                 _background=self.background,
@@ -231,16 +287,6 @@ class Format:
                 file=self.file,
                 flush=self.flush
             )
-        return self
-
-    def ljust(self, __width, __fillchar=" ", __parameter=0.35):
-        return self.__fill(__width, __fillchar, __type="L", __parameter=__parameter)
-
-    def rjust(self, __width, __fillchar=" ", __parameter=0.35):
-        return self.__fill(__width, __fillchar, __type="R", __parameter=__parameter)
-
-    def center(self, __width, __fillchar=" ", __parameter=0.35):
-        return self.__fill(__width, __fillchar, __type="C", __parameter=__parameter)
 
 
 def printf(
@@ -268,7 +314,7 @@ def printf(
     print(*value, sep=sep, end="\033[0m%s" % end, file=file, flush=flush)
 
 
-def str_just(_string, _length, _fillchar=" ", _type="L", _parameter=0.60):
+def str_just(_string, _length, _fill_char=" ", _type="L", _parameter=0.60):
     """
     中英文混合字符串对齐函数
     str_just(_string, _length[, _type]) -> str
@@ -276,7 +322,7 @@ def str_just(_string, _length, _fillchar=" ", _type="L", _parameter=0.60):
 
     :param _string:[str]需要对齐的字符串
     :param _length:[int]对齐长度
-    :param _fillchar:[str]填充字符
+    :param _fill_char:[str]填充字符
     :param _type:[str]对齐方式（'L'：默认，左对齐；'R'：右对齐；'C'或其他：居中对齐）
     :param _parameter:[float] 长度调节参数
     :return:[str]输出_string的对齐结果
@@ -298,7 +344,7 @@ def str_just(_string, _length, _fillchar=" ", _type="L", _parameter=0.60):
     else:
         _left = _space // 2
         _right = _space - _left
-    return "%s" % _fillchar * _left + _string + "%s" % _fillchar * _right
+    return "%s" % _fill_char * _left + _string + "%s" % _fill_char * _right
 
 
 if __name__ == '__main__':
